Learn R Programming

mfdb (version 7.4-0)

mfdb_aggregate_na_group: MareFrame DB aggregate NAs

Description

A decorator for other MFDB attributes to file NAs into another group, either one created by the main function or not.

Usage

mfdb_na_group(sub_aggregate, na_group)

Value

An mfdb_aggregate object that can then be used in querying functions such as mfdb_sample_count

Arguments

sub_aggregate

An mfdb_aggregate produced by another function, e.g. mfdb_step_interval

na_group

The group to assign NAs to, e.g. "len_unknown"

Details

The NA group won't be added to any aggregate files generated by MFDB, since the output would be invalid.

Examples

Run this code
length <- mfdb_na_group(mfdb_step_interval("len", 10), 'len_unknown')

Run the code above in your browser using DataLab