Learn R Programming

mfdb (version 7.4-0)

mfdb_helpers_mfdb_concatenate_results: MareFrame Query Utilities

Description

Aggregate data from the database in a variety of ways

Usage

mfdb_concatenate_results(...)

Value

Given any number of data.frames from mfdb query functions with identical columns, produces a combined data.frame, similar to rbind but preserving the attributes required to produce aggregation files.

Arguments

...

Any number of data.frames produced by mfdb query functions with identical columns, e.g. mfdb_sample_count