Learn R Programming

mfdb (version 7.4-0)

mfdb_aggregate_unaggregated: MareFrame DB unaggregated data

Description

Tell mfdb functions not to aggregate this column, just return all values.

Usage

mfdb_unaggregated(omitNA = FALSE, like = c(), not_like = c())

Value

An mfdb_aggregate object that can then be used in querying functions such as mfdb_sample_count

Arguments

omitNA

Skip over rows where column is NA

like

Vector of SQL like expressions to check column against

not_like

Vector of SQL like expressions to check column against

Details

SQL like expessions can use the wildcards "_" to match any character and "

Examples

Run this code
# All vessels with a name ending with 'e' or 'd'
mfdb_unaggregated(like = c("%e", "%d"))

Run the code above in your browser using DataLab