powered by
Tell mfdb functions not to aggregate this column, just return all values.
mfdb_unaggregated(omitNA = FALSE, like = c(), not_like = c())
An mfdb_aggregate object that can then be used in querying functions such as mfdb_sample_count
mfdb_aggregate
mfdb_sample_count
Skip over rows where column is NA
Vector of SQL like expressions to check column against
SQL like expessions can use the wildcards "_" to match any character and "
# All vessels with a name ending with 'e' or 'd' mfdb_unaggregated(like = c("%e", "%d"))
Run the code above in your browser using DataLab