Aggregate data from the database in a variety of ways
mfdb_concatenate_results(...)Given any number of data.frames from mfdb query functions with identical
columns, produces a combined data.frame, similar to rbind but
preserving the attributes required to produce aggregation files.
Any number of data.frames produced by mfdb query functions with identical columns, e.g. mfdb_sample_count